@@ -1,5 +1,5 @@
 #
-# $Id: List.pm,v 0.13 2004/12/05 16:07:34 dankogai Exp dankogai $
+# $Id: List.pm,v 0.12 2004/05/08 05:55:35 dankogai Exp dankogai $
 #
 package Regexp::List;
 use 5.006; # qr/(??{}/ needed
@@ -7,7 +7,7 @@ use strict;
 use warnings;
 no warnings 'uninitialized';
 #use base qw/Exporter/;
-our $VERSION = '0.16_001';
+our $VERSION = do { my @r = (q$Revision: 0.12 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 #our @EXPORT = qw();
 #our %EXPORT_TAGS = ( 'all' => [ qw() ] );
@@ -16,19 +16,11 @@ our $DEBUG     = 0;
 
 our $FILLER = "\x{fffd}"; # fallback
 
-# According "perlre", a "^" immediately after the "?" is a shorthand
-# equivalent to "d-imsx" since Perl 5.14.
-my $options = 'imsx\-';
-if ($^V gt v5.14.0) {
-    $options .= '^';
-}
-
-our $RE_PAREN; # predeclear
 our $RE_START =
     qr{(?:
     (?!\\)\((?:\?
     (?:
-     ([$options]*:)| # options 
+     ([imsx\-]*:)  | # options 
      \<?[\=\!]     | # look(behind|ahead)
      \#[^\)]+      | # comments
      #$RE_PAREN    | # ( condtion )
@@ -475,8 +467,8 @@ Regexp::List - builds regular expressions out of a list of words
 
   use Regexp::List;
   my $l  = Regexp::List->new;
-  my $re = $l->list2re(qw/foobar fooxar foozap fooza/);
-  # $re is now qr/foo(?:[bx]ar|zap?)/
+  my $re = $l->list2re(qw/foobar fooxar foozap/);
+  # $re is now qr/foo(?:[bx]ar|zap)/
 
 =head1 ABSTRACT
 
@@ -679,7 +671,7 @@ Mastering Regular Expressions  L<http://www.oreilly.com/catalog/regex2/>
 
 =head1 AUTHOR
 
-Dan Kogai <dankogai@dan.co.jp>, Kato Kazuyoshi <kato.kazuyoshi@gmail.com>
+Dan Kogai <dankogai@dan.co.jp>
 
 =head1 COPYRIGHT AND LICENSE
 
