@@ -1,13 +1,12 @@
 #
-# $Id: Optimizer.pm,v 0.15 2004/12/05 16:07:34 dankogai Exp dankogai $
+# $Id: Optimizer.pm,v 0.13 2004/05/08 05:55:35 dankogai Exp dankogai $
 #
 package Regexp::Optimizer;
 use 5.006; # qr/(??{}/ needed
 use strict;
 use warnings;
 use base qw/Regexp::List/;
-use charnames qw();
-our $VERSION = '0.16_001';
+our $VERSION = do { my @r = (q$Revision: 0.13 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 #our @EXPORT = qw();
 #our %EXPORT_TAGS = ( 'all' => [ qw() ] );
@@ -140,7 +139,6 @@ sub _optimize{
 	print STDERR '>'x $self->{_indent}, " ", $_[0], "\n";
     my ($result, $regopt)  = _strip(shift, 1);
     $result =~ s/\\([()])/"\\x" . sprintf("%X", ord($1))/ego;
-    $result =~ s/\\N{(.+?)}/"\\x" . sprintf("{%X}", charnames::vianame($1))/ego;
     # $result =~ s/(\s)/"\\x" . sprintf("%X", ord($1))/ego;
     $result !~ /$RE_PIPE/ and goto RESULT;
     my $l = $self->clone->set(%my_l2r_opts);
@@ -340,7 +338,7 @@ tested very well.
 =item *
 
 Regex parser in this module (which itself is implemented by regular
-expression) is not as thoroughly tested as L<Regexp::List>
+expression) is not as thoroughly tested as L<Regex::List>
 
 =item *
 
@@ -412,7 +410,7 @@ Mastering Regular Expressions  L<http://www.oreilly.com/catalog/regex2/>
 
 =head1 AUTHOR
 
-Dan Kogai <dankogai@dan.co.jp>, Kato Kazuyoshi <kato.kazuyoshi@gmail.com>
+Dan Kogai <dankogai@dan.co.jp>
 
 =head1 COPYRIGHT AND LICENSE
 
